--List of the products with a price greater than 50 euros.
SELECT * FROM PRODUCTS
WHERE PRICE > 50

--List products with category Alimentare having a price between 5 and 10 euros
SELECT * FROM PRODUCTS
WHERE PRICE >= 5 AND PRICE <= 10 AND CATEGORY = 'Alimentare'

--List Italian customers older than 50 years
SELECT * FROM CUSTOMERS
WHERE YEAR(CURRENT_TIMESTAMP) - YEAR_OF_BIRTH > 50

--List customers who wrote only reviews with rate greater than 4.
SELECT DISTINCT(c.ID), c.NAME, c.SURNAME 
FROM CUSTOMERS c INNER JOIN REVIEWS r 
ON c.ID = r.CUSTOMER
WHERE r.RATE > 4
EXCEPT
SELECT DISTINCT(c.ID), c.NAME, c.SURNAME 
FROM CUSTOMERS c INNER JOIN REVIEWS r 
ON c.ID = r.CUSTOMER
WHERE r.RATE <= 4

--List customers from Livorno with at least a review
SELECT DISTINCT(c.ID), c.NAME, c.SURNAME 
FROM CUSTOMERS c INNER JOIN REVIEWS r 
ON c.ID = r.CUSTOMER
WHERE c.CITY = 'Livorno'

--List customers from Livorno who bought products with category Arte
SELECT DISTINCT(c.ID), c.NAME, c.SURNAME
FROM CUSTOMERS c INNER JOIN PURCHASES v  
ON c.ID = v.CUSTOMER INNER JOIN PRODUCTS p 
ON p.ID = v.PRODUCT
WHERE p.CATEGORY = 'Arte' AND c.CITY = 'Livorno'


--List women who bought products with category Arte
SELECT DISTINCT(c.ID), c.NAME, c.SURNAME
FROM CUSTOMERS c INNER JOIN PURCHASES v  
ON c.ID = v.CUSTOMER INNER JOIN PRODUCTS p 
ON p.ID = v.PRODUCT
WHERE p.CATEGORY = 'Arte' AND c.SEX = 'F'


--List products that received reviews from customers from Pisa in the year 2013 and from
--Livorno or Florence in 2010.
SELECT DISTINCT(p.ID), p.DESCRIPTION
FROM CUSTOMERS c INNER JOIN REVIEWS r  
ON c.ID = r.CUSTOMER INNER JOIN PRODUCTS p 
ON p.ID = r.PRODUCT
WHERE (c.CITY = 'Pisa' AND YEAR(r.DATE) = 2013) OR 
(c.CITY = 'Livorno' OR c.CITY = 'Florence' AND YEAR(r.DATE) = 2010)

--5) List all products bought by at least a person from Livorno and having at 
--least a review from a female, with the text containing the word “porta”

SELECT DISTINCT(p.ID), p.DESCRIPTION
FROM CUSTOMERS c1 INNER JOIN PURCHASES v  
ON c1.ID = v.CUSTOMER INNER JOIN PRODUCTS p 
ON p.ID = v.PRODUCT INNER JOIN REVIEWS r
ON p.ID = r.PRODUCT INNER JOIN CUSTOMERS c2
ON c2.ID = r.CUSTOMER
WHERE c1.CITY = 'Livorno' AND c2.SEX = 'F' AND
r.TEXT LIKE '% porta %'

--10) List customers who brought ONLY products with a price less than 30 euro
SELECT DISTINCT(c1.ID), c1.NAME, c1.SURNAME
FROM CUSTOMERS c INNER JOIN PURCHASES v ON p.ID = v.PRODUCT
WHERE c.ID NOT IN (
    SELECT c.ID
    FROM CUSTOMERS c INNER JOIN PURCHASES v  
    ON c.ID = v.CUSTOMER INNER JOIN PRODUCTS p 
    ON p.ID = v.PRODUCT
    WHERE p.PRICE >= 30
)

-- 11) For each customer return the total amount spent in 2013
SELECT c.ID, c.NAME, c.SURNAME, SUM(p.PRICE)
FROM CUSTOMERS c INNER JOIN PURCHASES v  
ON c.ID = v.CUSTOMER INNER JOIN PRODUCTS p 
ON p.ID = v.PRODUCT
WHERE YEAR(v.DATE) = 2013
GROUP BY c.ID, c.NAME, c.SURNAME

-- 12) For each customer who bought at least 10 products return the average amount spent
SELECT c.ID, c.NAME, c.SURNAME, AVG(p.PRICE)
FROM CUSTOMERS c INNER JOIN PURCHASES v  
ON c.ID = v.CUSTOMER INNER JOIN PRODUCTS p 
ON p.ID = v.PRODUCT
GROUP BY c.ID, c.NAME, c.SURNAME
HAVING COUNT(*) >= 10

--13) For each product with category ARTE return the number of distinct customers 
--who bought that product and the total amount spent by those customers for that product
SELECT p.ID, p.DESCRIPTION, COUNT(DISTINCT(c.ID)), SUM(p.PRICE)
FROM CUSTOMERS c INNER JOIN PURCHASES v  
ON c.ID = v.CUSTOMER INNER JOIN PRODUCTS p 
ON p.ID = v.PRODUCT
WHERE p.CATEGORY = 'Arte'
GROUP BY p.ID, p.DESCRIPTION

--14) For each product with at least 3 reviews return the last date in which the product was bought
SELECT p.ID, p.DESCRIPTION, MAX(v.DATE)
FROM PRODUCTS p INNER JOIN REVIEWS r  
ON p.ID = r.PRODUCT INNER JOIN PURCHASES v
ON p.ID = v.PRODUCT
GROUP BY p.ID, p.DESCRIPTION
HAVING COUNT(*) >= 3